<?php

namespace Assetdocs\Manufacturer\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Assetdocs\Manufacturer\Models\Manufacturer;

class ManufacturerPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the manufacturer.
     *
     * @param User $user
     * @param Manufacturer $manufacturer
     *
     * @return bool
     */
    public function view(User $user, Manufacturer $manufacturer)
    {
        if ($user->canDo('manufacturer.manufacturer.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $manufacturer->user_id;
    }

    /**
     * Determine if the given user can create a manufacturer.
     *
     * @param User $user
     * @param Manufacturer $manufacturer
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('manufacturer.manufacturer.create');
    }

    /**
     * Determine if the given user can update the given manufacturer.
     *
     * @param User $user
     * @param Manufacturer $manufacturer
     *
     * @return bool
     */
    public function update(User $user, Manufacturer $manufacturer)
    {
        if ($user->canDo('manufacturer.manufacturer.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $manufacturer->user_id;
    }

    /**
     * Determine if the given user can delete the given manufacturer.
     *
     * @param User $user
     * @param Manufacturer $manufacturer
     *
     * @return bool
     */
    public function destroy(User $user, Manufacturer $manufacturer)
    {
        if ($user->canDo('manufacturer.manufacturer.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $manufacturer->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
